body {
  font-size: 12px;
  max-width: 100000px;
  padding: 0px;
  margin: 0px;
}
h1, h2, h3 {
	page-break-before: auto!important;
}
.sep {
  padding: 1em 0px;
  font-size : 0.9em;
}

.titlepage h1.main { /* Title */
	
}
.titlepage h1.subtitle, .titlepage p.subtitle { /* Subtitle */
	font-weight: normal!important;
	border: 0px;
	font-size: 1.1em;
	text-indent: 0px;
}
.titlepage p.author { /* Author */
	color : #565656;
	font-style: italic;
	text-indent: 0px;
}
.titlepage p.date { /* Date */
	display: none;
	text-indent: 0px;
}