div.toc {
  text-align: center;
}
#htmlbody div.toc {
  font-size : 1.1em;
}
div.toc ul {
  list-style-type: none;
  text-align: left;
}
div.toc > ul {
  margin: 0px;
  padding: 0px;
  display: inline-block;
}
#htmlbody div.toc li > a:after {
    content: "";
}