from .base import *
from .mdfilemods import *
from .stylemods import *

ALL_MODULES = [
	MainTargetDatasModule,
	ThemeModule,
	StyleModule,
	SepModule,
	FontModule,
	MetadataModule,
	LatexModule,
	ImagesModule,
	TitlePageModule,
	TocModule,
	HtmlBlocksModule,
]