<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8" />
<!-- <link href="https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,600;0,700;0,800;1,300;1,400;1,600;1,700;1,800&display=swap" rel="stylesheet"> -->
<title>{title}</title>
{headers}
</head>
<body id='htmlbody'>
{body}
</body>
</html>